Struct XxSessionV1
pub struct XxSessionV1 { /* private fields */ }wayland and Linux only.Expand description
A session for an application
A xx_session_v1 object represents a session for an application. While the object exists, all surfaces which have been added to the session will have states stored by the compositor which can be reapplied at a later time. Two sessions cannot exist for the same identifier string.
States for surfaces added to a session are automatically updated by the compositor when they are changed.
Surfaces which have been added to a session are automatically removed from the session if xdg_toplevel.destroy is called for the surface.
See also the Event enum for this interface.
Implementations
impl XxSessionV1
impl XxSessionV1
pub fn destroy(&self)
pub fn destroy(&self)
Destroy the session
Destroy a session object, preserving the current state but not continuing to make further updates if state changes occur. This makes the associated xx_toplevel_session_v1 objects inert.
pub fn remove(&self)
pub fn remove(&self)
Remove the session
Remove the session, making it no longer available for restoration. A compositor should in response to this request remove the data related to this session from its storage.
pub fn add_toplevel<U, D>(
&self,
toplevel: &XdgToplevel,
name: String,
qh: &QueueHandle<D>,
udata: U,
) -> XxToplevelSessionV1
pub fn add_toplevel<U, D>( &self, toplevel: &XdgToplevel, name: String, qh: &QueueHandle<D>, udata: U, ) -> XxToplevelSessionV1
add a new surface to the session
Attempt to add a given surface to the session. The passed name is used to identify what window is being restored, and may be used store window specific state within the session.
Calling this with a toplevel that is already managed by the session with the same associated will raise an in_use error.
pub fn restore_toplevel<U, D>(
&self,
toplevel: &XdgToplevel,
name: String,
qh: &QueueHandle<D>,
udata: U,
) -> XxToplevelSessionV1
pub fn restore_toplevel<U, D>( &self, toplevel: &XdgToplevel, name: String, qh: &QueueHandle<D>, udata: U, ) -> XxToplevelSessionV1
restore a surface state
Inform the compositor that the toplevel associated with the passed name should have its window management state restored.
Calling this with a toplevel that is already managed by the session with the same associated will raise an in_use error.
This request must be called prior to the first commit on the associated wl_surface, otherwise an already_mapped error is raised.
As part of the initial configure sequence, if the toplevel was successfully restored, a xx_toplevel_session_v1.restored event is emitted. See the xx_toplevel_session_v1.restored event for further details.